@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -32,16 +32,8 @@ namespace U2 {
 /************************************************************************/
 /* Triplet */
 /************************************************************************/
-U2Triplet::U2Triplet(const QString &_key, const QString &_role, const QString &_value)
-: id(-1), key(_key), role(_role), value(_value)
-{
-
-}
-
-U2Triplet::U2Triplet(const U2Triplet& other)
-: id(other.id), key(other.key), role(other.role), value(other.value)
-{
-
+U2Triplet::U2Triplet(const QString& _key, const QString& _role, const QString& _value)
+    : id(-1), key(_key), role(_role), value(_value) {
 }
 
 QString U2Triplet::getKey() const {
@@ -59,13 +51,11 @@ QString U2Triplet::getValue() const {
 /************************************************************************/
 /* Owner */
 /************************************************************************/
-Owner::Owner(const QString &_name)
-: id(-1), name(_name)
-{
-
+Owner::Owner(const QString& _name)
+    : id(-1), name(_name) {
 }
 
-Owner::Owner(const Owner &owner) {
+Owner::Owner(const Owner& owner) {
     id = owner.id;
     name = owner.name;
 }
@@ -86,8 +76,8 @@ U2SQLiteTripleStore::~U2SQLiteTripleStore() {
     delete db;
 }
 
-void U2SQLiteTripleStore::init(const QString &url, U2OpStatus &os) {
-    if (db->handle != NULL) {
+void U2SQLiteTripleStore::init(const QString& url, U2OpStatus& os) {
+    if (db->handle != nullptr) {
         os.setError(TripleStoreL10N::tr("Database is already opened!"));
         return;
     }
@@ -105,9 +95,9 @@ void U2SQLiteTripleStore::init(const QString &url, U2OpStatus &os) {
         int flags = SQLITE_OPEN_READWRITE;
         flags |= SQLITE_OPEN_CREATE;
         QByteArray file = url.toUtf8();
-        int rc = sqlite3_open_v2(file.constData(), &db->handle, flags, NULL);
+        int rc = sqlite3_open_v2(file.constData(), &db->handle, flags, nullptr);
         if (rc != SQLITE_OK) {
-            QString err = db->handle == NULL ? QString(" error-code: %1").arg(rc) : QString(sqlite3_errmsg(db->handle));
+            QString err = db->handle == nullptr ? QString(" error-code: %1").arg(rc) : QString(sqlite3_errmsg(db->handle));
             os.setError(TripleStoreL10N::tr("Error opening SQLite database: %1!").arg(err));
             break;
         }
@@ -134,20 +124,20 @@ void U2SQLiteTripleStore::init(const QString &url, U2OpStatus &os) {
 
     if (os.hasError()) {
         sqlite3_close(db->handle);
-        db->handle = NULL;
+        db->handle = nullptr;
         state = U2DbiState_Void;
         return;
     }
     state = U2DbiState_Ready;
 }
 
-static int isEmptyCallback(void *o, int argc, char ** /*argv*/, char ** /*column*/) {
+static int isEmptyCallback(void* o, int argc, char** /*argv*/, char** /*column*/) {
     int* res = (int*)o;
     *res = argc;
     return 0;
 }
 
-bool U2SQLiteTripleStore::isEmpty(U2OpStatus &os) const {
+bool U2SQLiteTripleStore::isEmpty(U2OpStatus& os) const {
     QMutexLocker lock(&db->lock);
     QByteArray showTablesQuery = "SELECT * FROM sqlite_master WHERE type='table';";
     int nTables = 0;
@@ -161,14 +151,17 @@ bool U2SQLiteTripleStore::isEmpty(U2OpStatus &os) const {
     return nTables == 0;
 }
 
-void U2SQLiteTripleStore::createTables(U2OpStatus &os) {
+void U2SQLiteTripleStore::createTables(U2OpStatus& os) {
     QMutexLocker lock(&db->lock);
     SQLiteWriteQuery("CREATE TABLE Triplets (id INTEGER PRIMARY KEY AUTOINCREMENT, "
-        "key TEXT NOT NULL, role TEXT NOT NULL, value TEXT NOT NULL)", db, os).execute();
+                     "key TEXT NOT NULL, role TEXT NOT NULL, value TEXT NOT NULL)",
+                     db,
+                     os)
+        .execute();
 }
 
-void U2SQLiteTripleStore::shutdown(U2OpStatus &os) {
-    if (db == NULL) {
+void U2SQLiteTripleStore::shutdown(U2OpStatus& os) {
+    if (db == nullptr) {
         os.setError(TripleStoreL10N::tr("Database is already closed!"));
         return;
     }
@@ -182,16 +175,16 @@ void U2SQLiteTripleStore::shutdown(U2OpStatus &os) {
         int rc = sqlite3_close(db->handle);
 
         if (rc != SQLITE_OK) {
-            QString err = db->handle == NULL ? QString(" error-code: %1").arg(rc) : QString(sqlite3_errmsg(db->handle));
+            QString err = db->handle == nullptr ? QString(" error-code: %1").arg(rc) : QString(sqlite3_errmsg(db->handle));
             ioLog.error(TripleStoreL10N::tr("Failed to close triple store database: %1").arg(err));
         }
-        db->handle = NULL;
+        db->handle = nullptr;
     }
     state = U2DbiState_Void;
     return;
 }
 
-void U2SQLiteTripleStore::addValue(const U2Triplet &value, U2OpStatus &os) {
+void U2SQLiteTripleStore::addValue(const U2Triplet& value, U2OpStatus& os) {
     QMutexLocker lock(&db->lock);
     bool found = false;
 
@@ -199,19 +192,19 @@ void U2SQLiteTripleStore::addValue(const U2Triplet &value, U2OpStatus &os) {
     this->getTripletId(value, found, os);
     CHECK_OP(os, );
 
-    if (!found) { // insert triplet
+    if (!found) {  // insert triplet
         this->insertTriplet(value, os);
         CHECK_OP(os, );
     }
 }
 
-bool U2SQLiteTripleStore::contains(const QString &key, const QString &role, U2OpStatus &os) const {
+bool U2SQLiteTripleStore::contains(const QString& key, const QString& role, U2OpStatus& os) const {
     QMutexLocker lock(&db->lock);
     QString value = this->getValue(key, role, os);
     return !value.isEmpty();
 }
 
-bool U2SQLiteTripleStore::contains(const U2Triplet &value, U2OpStatus &os) const {
+bool U2SQLiteTripleStore::contains(const U2Triplet& value, U2OpStatus& os) const {
     QMutexLocker lock(&db->lock);
     static const QString queryString("SELECT t.id FROM Triplets t WHERE t.key = ?1 AND t.role = ?2 AND t.value = ?3");
     SQLiteReadQuery q(queryString, db, os);
@@ -227,7 +220,7 @@ bool U2SQLiteTripleStore::contains(const U2Triplet &value, U2OpStatus &os) const
     return false;
 }
 
-QString U2SQLiteTripleStore::getValue(const QString &key, const QString &role, U2OpStatus &os) const {
+QString U2SQLiteTripleStore::getValue(const QString& key, const QString& role, U2OpStatus& os) const {
     QMutexLocker lock(&db->lock);
     static const QString queryString("SELECT t.value FROM Triplets t WHERE t.key = ?1 AND t.role = ?2 ORDER BY t.id");
     SQLiteReadQuery q(queryString, db, os);
@@ -241,7 +234,7 @@ QString U2SQLiteTripleStore::getValue(const QString &key, const QString &role, U
     return results.isEmpty() ? "" : results.last();
 }
 
-qint64 U2SQLiteTripleStore::getTripletId(const U2Triplet &triplet, bool &found, U2OpStatus &os) const {
+qint64 U2SQLiteTripleStore::getTripletId(const U2Triplet& triplet, bool& found, U2OpStatus& os) const {
     QMutexLocker lock(&db->lock);
     static const QString queryString("SELECT t.id FROM Triplets t WHERE t.key = ?1 AND t.role = ?2 AND t.value = ?3");
     SQLiteReadQuery q(queryString, db, os);
@@ -259,7 +252,7 @@ qint64 U2SQLiteTripleStore::getTripletId(const U2Triplet &triplet, bool &found,
     return 0;
 }
 
-qint64 U2SQLiteTripleStore::insertTriplet(const U2Triplet &triplet, U2OpStatus &os) {
+qint64 U2SQLiteTripleStore::insertTriplet(const U2Triplet& triplet, U2OpStatus& os) {
     QMutexLocker lock(&db->lock);
     static const QString queryString("INSERT INTO Triplets(key, role, value) VALUES(?1, ?2, ?3)");
     SQLiteWriteQuery q(queryString, db, os);
@@ -270,7 +263,7 @@ qint64 U2SQLiteTripleStore::insertTriplet(const U2Triplet &triplet, U2OpStatus &
     return q.insert();
 }
 
-void U2SQLiteTripleStore::removeTriplet(qint64 tripletId, U2OpStatus &os) {
+void U2SQLiteTripleStore::removeTriplet(qint64 tripletId, U2OpStatus& os) {
     QMutexLocker lock(&db->lock);
     static const QString queryString("DELETE FROM Triplets WHERE id = ?1");
     SQLiteWriteQuery q(queryString, db, os);
@@ -279,7 +272,7 @@ void U2SQLiteTripleStore::removeTriplet(qint64 tripletId, U2OpStatus &os) {
     q.execute();
 }
 
-QList<U2Triplet> U2SQLiteTripleStore::getTriplets(U2OpStatus &os) const {
+QList<U2Triplet> U2SQLiteTripleStore::getTriplets(U2OpStatus& os) const {
     QMutexLocker lock(&db->lock);
     static const QString queryString("SELECT t.id, t.key, t.role, t.value FROM Triplets t");
     SQLiteReadQuery q(queryString, db, os);
@@ -288,12 +281,12 @@ QList<U2Triplet> U2SQLiteTripleStore::getTriplets(U2OpStatus &os) const {
     while (q.step()) {
         U2Triplet t(q.getString(1), q.getString(2), q.getString(3));
         t.id = q.getInt64(0);
-        result << t;
+        result.append(t);
     }
     return result;
 }
 
-void U2SQLiteTripleStore::removeValue(const U2Triplet &value, U2OpStatus &os) {
+void U2SQLiteTripleStore::removeValue(const U2Triplet& value, U2OpStatus& os) {
     QMutexLocker lock(&db->lock);
     static const QString queryString("DELETE FROM Triplets WHERE id = ?1");
     SQLiteWriteQuery q(queryString, db, os);
@@ -302,4 +295,4 @@ void U2SQLiteTripleStore::removeValue(const U2Triplet &value, U2OpStatus &os) {
     q.execute();
 }
 
-} // U2
+}  // namespace U2
