@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -28,8 +28,9 @@ namespace U2 {
 void TaskStarter::registerTask() {
     switch (condition) {
         case NoProject:
-            if (NULL != AppContext::getProject()) {
-                delete t; t = NULL;
+            if (AppContext::getProject() != nullptr) {
+                delete t;
+                t = nullptr;
                 return;
             }
             break;
@@ -41,10 +42,10 @@ void TaskStarter::registerTask() {
 
     if (t) {
         AppContext::getTaskScheduler()->registerTopLevelTask(t);
-        t = NULL;
+        t = nullptr;
     }
 
     deleteLater();
 }
 
-} //namespace
+}  // namespace U2
