@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,32 +19,30 @@
  * MA 02110-1301, USA.
  */
 
-#include <U2Core/U2SafePoints.h>
-
 #include "ColumnDataParser.h"
 
+#include <U2Core/U2SafePoints.h>
+
 namespace U2 {
 
-ColumnDataParser::Column::Column(const QString &_name,
-    ColumnDataParser::ColumnType _type, const QString _defaultValue, bool _required)
-: name(_name), type(_type), defaultValue(_defaultValue), required(_required)
-{
-
+ColumnDataParser::Column::Column(const QString& _name,
+                                 ColumnDataParser::ColumnType _type,
+                                 const QString _defaultValue,
+                                 bool _required)
+    : name(_name), type(_type), defaultValue(_defaultValue), required(_required) {
 }
 
-ColumnDataParser::Column::Column(const QString &_name)
-: name(_name), type(STRING)
-{
+ColumnDataParser::Column::Column(const QString& _name)
+    : name(_name), type(STRING) {
     required = false;
 }
 
-bool ColumnDataParser::Column::operator == (const ColumnDataParser::Column &other) const {
+bool ColumnDataParser::Column::operator==(const ColumnDataParser::Column& other) const {
     return name == other.name;
 }
 
-ColumnDataParser::Iterator::Iterator(const QList<Column> &_columns, const QStringList &_values)
-: columns(_columns), values(_values)
-{
+ColumnDataParser::Iterator::Iterator(const QList<Column>& _columns, const QStringList& _values)
+    : columns(_columns), values(_values) {
     currentNum = 0;
     end = columns.size();
     if (columns.size() != values.size()) {
@@ -75,7 +73,7 @@ QString ColumnDataParser::Iterator::takeString() {
     return take();
 }
 
-int ColumnDataParser::Iterator::takeInt(U2OpStatus &os) {
+int ColumnDataParser::Iterator::takeInt(U2OpStatus& os) {
     bool ok = true;
     QString str = take();
     int result = str.toInt(&ok);
@@ -85,7 +83,7 @@ int ColumnDataParser::Iterator::takeInt(U2OpStatus &os) {
     return result;
 }
 
-double ColumnDataParser::Iterator::takeDouble(U2OpStatus &os) {
+double ColumnDataParser::Iterator::takeDouble(U2OpStatus& os) {
     bool ok = true;
     QString str = take();
     double result = str.toDouble(&ok);
@@ -112,17 +110,15 @@ QString ColumnDataParser::Iterator::look() const {
     return values[currentNum];
 }
 
-ColumnDataParser::ColumnDataParser(const QList<Column> &_formatColumns, const QString &_separator)
-: inited(false), formatColumns(_formatColumns), separator(_separator)
-{
-
+ColumnDataParser::ColumnDataParser(const QList<Column>& _formatColumns, const QString& _separator)
+    : inited(false), formatColumns(_formatColumns), separator(_separator) {
 }
 
-void ColumnDataParser::init(const QString &headerLine, U2OpStatus &os) {
+void ColumnDataParser::init(const QString& headerLine, U2OpStatus& os) {
     QStringList names = headerLine.split(separator, QString::SkipEmptyParts);
-    foreach (const QString &name, names) {
+    for (const QString& name : qAsConst(names)) {
         if (formatColumns.contains(Column(name))) {
-            foreach (const Column &c, formatColumns) {
+            for (const Column& c : qAsConst(formatColumns)) {
                 if (name == c.name) {
                     currentColumns << c;
                     break;
@@ -133,7 +129,7 @@ void ColumnDataParser::init(const QString &headerLine, U2OpStatus &os) {
         }
     }
     // check required colums
-    foreach (const Column &c, formatColumns) {
+    foreach (const Column& c, formatColumns) {
         if (c.required && !currentColumns.contains(c)) {
             os.setError(QString("Required column is missed: %1").arg(c.name));
             return;
@@ -142,7 +138,7 @@ void ColumnDataParser::init(const QString &headerLine, U2OpStatus &os) {
     inited = true;
 }
 
-ColumnDataParser::Iterator ColumnDataParser::parseLine(const QString &line, U2OpStatus &os) const {
+ColumnDataParser::Iterator ColumnDataParser::parseLine(const QString& line, U2OpStatus& os) const {
     SAFE_POINT(inited, "ColumnDataParser is not inited", Iterator(QList<Column>(), QStringList()));
     QStringList values = line.split(separator, QString::SkipEmptyParts);
     if (currentColumns.size() != values.size()) {
@@ -152,8 +148,8 @@ ColumnDataParser::Iterator ColumnDataParser::parseLine(const QString &line, U2Op
     return Iterator(currentColumns, values);
 }
 
-const QList<ColumnDataParser::Column> & ColumnDataParser::getCurrentColumns() const {
+const QList<ColumnDataParser::Column>& ColumnDataParser::getCurrentColumns() const {
     return currentColumns;
 }
 
-} // U2
+}  // namespace U2
