@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,13 +19,12 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_RELOAD_DOCUMENTS_TASK_
-#define _U2_RELOAD_DOCUMENTS_TASK_
+#pragma once
 
 #include <QCoreApplication>
 
-#include <U2Core/Task.h>
 #include <U2Core/DocumentModel.h>
+#include <U2Core/Task.h>
 
 namespace U2 {
 
@@ -38,11 +37,10 @@ private:
     void prepare() override;
     ReportResult report() override;
     QString generateReport() const override;
-    QList<Task *> onSubTaskFinished(Task* subTask) override;
+    QList<Task*> onSubTaskFinished(Task* subTask) override;
 
     QList<Document*> docs2Reload;
     QStringList subTaskStateInfoErrors;
 };
 
-}// namespace U2
-#endif
+}  // namespace U2
