@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,80 +19,82 @@
  * MA 02110-1301, USA.
  */
 
-#include <QPushButton>
+#include "ExportHighlightedDialogController.h"
+
 #include <QMessageBox>
-#include <ui_ExportHighlightedDialog.h>
 
 #include <U2Core/AppContext.h>
 #include <U2Core/AppSettings.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/GUrlUtils.h>
+#include <U2Core/U2SafePoints.h>
 #include <U2Core/UserApplicationsSettings.h>
 
 #include <U2Gui/HelpButton.h>
 #include <U2Gui/SaveDocumentController.h>
 
-#include "ExportHighlightedDialogController.h"
-#include "ov_msa/MSAEditorSequenceArea.h"
+#include "ov_msa/MaEditorSelection.h"
+#include "ov_msa/MsaEditorSequenceArea.h"
+#include "ui_ExportHighlightedDialog.h"
 
-namespace U2{
+namespace U2 {
 
-ExportHighligtingDialogController::ExportHighligtingDialogController(MSAEditorUI *msaui_, QWidget* p )
+ExportHighligtingDialogController::ExportHighligtingDialogController(MaEditorWgt* msaui_, QWidget* p)
     : QDialog(p),
       msaui(msaui_),
-      saveController(NULL),
-      ui(new Ui_ExportHighlightedDialog())
-{
+      saveController(nullptr),
+      ui(new Ui_ExportHighlightedDialog()) {
     ui->setupUi(this);
-    new HelpButton(this, ui->buttonBox, "18223058");
+    new HelpButton(this, ui->buttonBox, "96666040");
 
     ui->buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Export"));
     ui->buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
 
     CHECK(AppContext::getAppSettings(), );
     CHECK(AppContext::getAppSettings()->getUserAppsSettings(), );
-    CHECK(msaui->getEditor(), );
-    CHECK(msaui->getEditor()->getMSAObject(), );
+    const MaEditor* editor = msaui->getEditor();
+    CHECK(editor, );
 
     initSaveController();
 
-    connect(ui->endPosBox, SIGNAL(valueChanged(int)), SLOT(endPosValueChanged()));
+    int alignLength = editor->getAlignmentLen();
+    const MaEditorSelection& selection = editor->getSelection();
 
-    int alignLength = msaui->getEditor()->getMSAObject()->getLength();
-    QRect selection = msaui->getSequenceArea()->getSelection().getRect();
-
-    int startPos = -1;
-    int endPos = -1;
-    if (selection.isNull()) {
+    if (selection.isEmpty() || selection.isSingleColumnSelection()) {
         startPos = 1;
         endPos = alignLength;
     } else {
-        startPos = selection.x() + 1;
-        endPos = selection.x() + selection.width();
+        const QRect& selectionRect = selection.getRectList()[0];
+        startPos = selectionRect.x() + 1;
+        endPos = selectionRect.x() + selectionRect.width();
     }
 
-    ui->startPosBox->setMaximum(endPos);
-    ui->endPosBox->setMaximum(alignLength);
+    ui->startLineEdit->setMinimum(1);
+    ui->endLineEdit->setMinimum(1);
 
-    ui->startPosBox->setMinimum(1);
-    ui->endPosBox->setMinimum(2);
+    ui->startLineEdit->setMaximum(alignLength);
+    ui->endLineEdit->setMaximum(alignLength);
 
-    ui->startPosBox->setValue(startPos);
-    ui->endPosBox->setValue(endPos);
+    ui->startLineEdit->setValue(startPos);
+    ui->endLineEdit->setValue(endPos);
+
+    connect(ui->startLineEdit, SIGNAL(valueChanged(int)), SLOT(sl_regionChanged()));
+    connect(ui->endLineEdit, SIGNAL(valueChanged(int)), SLOT(sl_regionChanged()));
 }
-ExportHighligtingDialogController::~ExportHighligtingDialogController(){
+
+ExportHighligtingDialogController::~ExportHighligtingDialogController() {
     delete ui;
 }
 
-void ExportHighligtingDialogController::accept(){
-    startPos = ui->startPosBox->value();
-    endPos = ui->endPosBox->value();
-    if(ui->oneIndexRB->isChecked()){
+void ExportHighligtingDialogController::accept() {
+    startPos = ui->startLineEdit->value();
+    endPos = ui->endLineEdit->value();
+    if (ui->oneIndexRB->isChecked()) {
         startingIndex = 1;
-    }else{
+    } else {
         startingIndex = 0;
     }
-    if (saveController->getSaveFileName().isEmpty()){
+    if (saveController->getSaveFileName().isEmpty()) {
         QMessageBox::warning(this, tr("Warning"), tr("Export to file URL is empty!"));
         return;
     }
@@ -104,18 +106,27 @@ void ExportHighligtingDialogController::accept(){
     QDialog::accept();
 }
 
-void ExportHighligtingDialogController::lockKeepGaps(){
+void ExportHighligtingDialogController::lockKeepGaps() {
     ui->keepGapsBox->setChecked(true);
     ui->keepGapsBox->setDisabled(true);
 }
 
-void ExportHighligtingDialogController::endPosValueChanged(){
-    ui->startPosBox->setMaximum(ui->endPosBox->value() - 1);
+void ExportHighligtingDialogController::sl_regionChanged() {
+    bool validRange = ui->endLineEdit->value() - ui->startLineEdit->value() >= 0;
+    ui->buttonBox->button(QDialogButtonBox::Ok)->setEnabled(validRange);
+
+    if (validRange) {
+        ui->startLineEdit->setStyleSheet("QSpinBox {}");
+        ui->endLineEdit->setStyleSheet("QSpinBox {}");
+    } else {
+        ui->startLineEdit->setStyleSheet("QSpinBox { background-color: rgb(255, 200, 200); }");
+        ui->endLineEdit->setStyleSheet("QSpinBox { background-color: rgb(255, 200, 200); }");
+    }
 }
 
 void ExportHighligtingDialogController::initSaveController() {
     SaveDocumentControllerConfig config;
-    config.defaultFileName = GUrlUtils::getDefaultDataPath() + "/" + msaui->getEditor()->getMSAObject()->getGObjectName() + "_highlighting.txt";
+    config.defaultFileName = GUrlUtils::getDefaultDataPath() + "/" + msaui->getEditor()->getMaObject()->getGObjectName() + "_highlighting.txt";
     config.defaultFormatId = BaseDocumentFormats::PLAIN_TEXT;
     config.fileDialogButton = ui->fileButton;
     config.fileNameEdit = ui->fileNameEdit;
@@ -127,4 +138,4 @@ void ExportHighligtingDialogController::initSaveController() {
     saveController = new SaveDocumentController(config, formats, this);
 }
 
-}
+}  // namespace U2
