@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,22 +19,21 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef GTGRAPHICSITEM_H
-#define GTGRAPHICSITEM_H
+#pragma once
+
+#include <QGraphicsItem>
 
 #include <U2Core/U2OpStatus.h>
+
 #include "GTGlobals.h"
-#include <QGraphicsItem>
 
 namespace U2 {
 using namespace HI;
 
 class GTGraphicsItem {
 public:
-    static QRect getGraphicsItemRect(HI::GUITestOpStatus &os, QGraphicsItem *it);
-    static QPoint getItemCenter(HI::GUITestOpStatus &os, QGraphicsItem *it);
+    static QRect getGraphicsItemRect(QGraphicsItem* it);
+    static QPoint getItemCenter(QGraphicsItem* it);
 };
 
-} //namespace
-
-#endif // GTGRAPHICSITEM_H
+}  // namespace U2
