@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,22 +19,23 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GT_RUNNABLES_EXPORT_MSA2MSA_DIALOG_FILLER_H_
-#define _U2_GT_RUNNABLES_EXPORT_MSA2MSA_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
 namespace U2 {
 using namespace HI;
 
-    class ExportMSA2MSADialogFiller : public Filler {
-    public:
-        ExportMSA2MSADialogFiller(HI::GUITestOpStatus &_os, int _formatVal = -1, QString _path="");
-        void commonScenario();
-    private:
-        int formatVal;
-        QString path;
-    };
-}
+class ExportMSA2MSADialogFiller : public Filler {
+public:
+    ExportMSA2MSADialogFiller(int _formatVal = -1, QString _path = "", bool includeGaps = false, bool unknownAsGaps = false, int frame = 1);
+    void commonScenario() override;
 
-#endif
+private:
+    int formatVal;
+    QString path;
+    bool includeGaps = false;
+    bool unknownAsGaps = false;
+    int frame = 1;
+};
+}  // namespace U2
