@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -40,7 +40,7 @@ public:
     };
 
     AddPrimerDialogFiller(const Parameters& parameters);
-    void commonScenario();
+    void commonScenario() override;
 
 private:
     Parameters parameters;
