@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SPADES_SLOT_RELATION_DESCRIPTOR_H_
-#define _U2_SPADES_SLOT_RELATION_DESCRIPTOR_H_
+#pragma once
 
 #include <U2Lang/SlotRelation.h>
 
@@ -30,11 +29,9 @@ class SpadesSlotRelationDescriptor : public SlotRelationDescriptor {
 public:
     SpadesSlotRelationDescriptor(const QString& portId, const QString& slotId);
 
-    SpadesSlotRelationDescriptor *clone() const;
+    SpadesSlotRelationDescriptor* clone() const;
 
     bool isSlotEnabled(const QVariant& attrValue) const;
 };
 
-}   // namespace U2
-
-#endif // _U2_SPADES_SLOT_RELATION_DESCRIPTOR_H_
+}  // namespace U2
