@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,25 +20,25 @@
  */
 
 #include "LinkDataSupportPlugin.h"
-#include "LinkDataScriptLibrary.h"
 
 #include <U2Core/AppContext.h>
 
+#include "LinkDataScriptLibrary.h"
+
 namespace U2 {
 
 extern "C" Q_DECL_EXPORT Plugin* U2_PLUGIN_INIT_FUNC() {
-    LinkDataSupportPlugin * plug = new LinkDataSupportPlugin();
+    auto plug = new LinkDataSupportPlugin();
     return plug;
 }
 
 LinkDataSupportPlugin::LinkDataSupportPlugin()
-: Plugin(tr("LinkData Support"), tr("LinkData Support"))
-{
+    : Plugin(tr("LinkData Support"), tr("LinkData Support")) {
     AppContext::getWorkflowScriptRegistry()->registerScriptFactory(new LinkDataScriptFactory());
 }
 
-void LinkDataScriptFactory::createScript(WorkflowScriptEngine *engine) {
+void LinkDataScriptFactory::createScript(WorkflowScriptEngine* engine) {
     LinkDataScriptLibrary::init(engine);
 }
 
-} //U2
+}  // namespace U2
