@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,10 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_EXPORT_PRIMERS_DIALOG_H_
-#define _U2_EXPORT_PRIMERS_DIALOG_H_
+#pragma once
+
+#include <U2Core/Primer.h>
 
-#include "Primer.h"
 #include "ui_ExportPrimersDialog.h"
 
 namespace U2 {
@@ -33,32 +33,18 @@ class SaveDocumentController;
 class ExportPrimersDialog : public QDialog, private Ui_ExportPrimersDialog {
     Q_OBJECT
 public:
-    ExportPrimersDialog(const QList<Primer> &primers, QWidget *parent);
+    ExportPrimersDialog(const QList<Primer>& primers, QWidget* parent);
 
 private slots:
-    void sl_updateState();
-    void sl_connect();
-    void sl_connectionCompleted();
-    void sl_documentAdded(Document *document);
-    void sl_documentRemoved(Document *document);
-    void sl_folderBrowse();
-    void accept();
+    void accept() override;
 
 private:
     void init();
-    void initDatabases();
     void initSaveController();
     void connectSignals();
     void connectProjectSignals();
-    bool isFileMode() const;
-
     QList<Primer> primers;
-    SaveDocumentController *saveController;
-
-    static const QString LOCAL_FILE;
-    static const QString SHARED_DB;
+    SaveDocumentController* saveController;
 };
 
-}   // namespace U2
-
-#endif // _U2_EXPORT_PRIMERS_DIALOG_H_
+}  // namespace U2
