@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,13 +19,13 @@
  * MA 02110-1301, USA.
  */
 
+#include <AppContextImpl.h>
+
 #include <QDomDocument>
 #include <QMainWindow>
 #include <QMessageBox>
 #include <QMutex>
 
-#include <AppContextImpl.h>
-
 #include <U2Core/AppSettings.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/CMDLineUtils.h>
@@ -60,22 +60,22 @@
 namespace U2 {
 
 //////////////////////////////////////////////////////////////////////////
-///Close project
-CloseProjectTask::CloseProjectTask() : Task(tr("Close project"), TaskFlags(TaskFlag_NoRun) | TaskFlag_CancelOnSubtaskCancel)
-{
+/// Close project
+CloseProjectTask::CloseProjectTask()
+    : Task(tr("Close project"), TaskFlags(TaskFlag_NoRun) | TaskFlag_CancelOnSubtaskCancel) {
 }
 
 void CloseProjectTask::prepare() {
-    if (AppContext::getProject()==NULL) {
-        stateInfo.setError(  tr("No active project found") );
+    if (AppContext::getProject() == nullptr) {
+        stateInfo.setError(tr("No active project found"));
         return;
     }
-    /* TODO: this is done by project view. Need to cleanup this part! 
+    /* TODO: this is done by project view. Need to cleanup this part!
     addSubTask(new SaveProjectTask(SaveProjectTaskKind_SaveProjectAndDocumentsAskEach));
     */
     QList<Task*> tasks;
     /**/
-    Project *pp = AppContext::getProject();
+    Project* pp = AppContext::getProject();
     if (pp->isTreeItemModified()) {
         tasks.append(AppContext::getProjectService()->saveProjectTask(SaveProjectTaskKind_SaveProjectAndDocumentsAskEach));
     }
@@ -88,29 +88,27 @@ void CloseProjectTask::prepare() {
     addSubTask(new MultiTask(tr("Save and close project"), tasks));
 }
 
-
 //////////////////////////////////////////////////////////////////////////
 /// OpenProjectTask
-OpenProjectTask::OpenProjectTask(const QString& _url, const QString& _name) 
-    : Task(tr("Open project/document"), TaskFlags_NR_FOSCOE), url(_url), name(_name), loadProjectTask(NULL)
-{
+OpenProjectTask::OpenProjectTask(const QString& _url, const QString& _name)
+    : Task(tr("Open project/document"), TaskFlags_NR_FOSCOE), url(_url), name(_name), loadProjectTask(nullptr) {
 }
 
 void OpenProjectTask::prepare() {
     QFileInfo f(url);
     if (f.exists() && !(f.isFile() && f.isReadable())) {
-        stateInfo.setError(  tr("Not a readable file: %1").arg(url) );
+        stateInfo.setError(tr("Not a readable file: %1").arg(url));
         return;
     }
-    if (AppContext::getProject() != NULL) {
+    if (AppContext::getProject() != nullptr) {
         addSubTask(new CloseProjectTask());
-    }        
+    }
 
     if (f.exists()) {
         loadProjectTask = new LoadProjectTask(url);
         addSubTask(loadProjectTask);
     } else {
-        ProjectImpl* p =  new ProjectImpl(name, url);
+        auto p = new ProjectImpl(name, url);
         addSubTask(new RegisterProjectServiceTask(p));
         //     addSubTask(new SaveProjectTask(SaveProjectTaskKind_SaveProjectOnly, p));
     }
@@ -119,7 +117,7 @@ void OpenProjectTask::prepare() {
 QList<Task*> OpenProjectTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
     if (!isCanceled() && subTask == loadProjectTask && !loadProjectTask->hasError()) {
-        Project* p =  loadProjectTask->detachProject();
+        Project* p = loadProjectTask->detachProject();
         res.append(new RegisterProjectServiceTask(p));
     }
     return res;
@@ -127,35 +125,39 @@ QList<Task*> OpenProjectTask::onSubTaskFinished(Task* subTask) {
 
 //////////////////////////////////////////////////////////////////////////
 /// Save project
-SaveProjectTask::SaveProjectTask(SaveProjectTaskKind _k, Project* p, const QString& _url, bool silentSave_) 
-    : Task(tr("Save project"), TaskFlags(TaskFlag_NoRun) | TaskFlag_CancelOnSubtaskCancel), k(_k), proj(p), url(_url), silentSave(silentSave_)
-{
-}
-
-SaveProjectTask::~SaveProjectTask () {
+SaveProjectTask::SaveProjectTask(SaveProjectTaskKind _k, Project* p, const QString& _url, bool silentSave_)
+    : Task(tr("Save project"), TaskFlags(TaskFlag_NoRun) | TaskFlag_CancelOnSubtaskCancel), k(_k), proj(p), url(_url), silentSave(silentSave_) {
 }
 
 void SaveProjectTask::prepare() {
-    if (proj == NULL) {
+    if (proj == nullptr) {
         proj = AppContext::getProject();
     }
-    assert(proj!=NULL);
+    SAFE_POINT(proj != nullptr, "Project is null", );
+    bool isGuiTestShutdown = qgetenv("UGENE_GUI_TEST_SHUTDOWN") == "1";
+    if (isGuiTestShutdown) {
+        // There is no need to save project during GUI tests shutdown.
+        // The testing is already finished at that moment.
+        uiLog.trace("Skipping SaveProjectTask job because UGENE_GUI_TEST_SHUTDOWN = 1");
+        return;
+    }
+
     if (url.isEmpty()) {
         url = proj->getProjectURL();
     }
-    QList<Task *> ssTasks;
+    QList<Task*> ssTasks;
     if (url.isEmpty() && (!proj->getGObjectViewStates().isEmpty() || proj->getDocuments().size() > 0)) {
-        //show "save project?" dialog, if needed
+        // show "save project?" dialog, if needed
         int savedSaveProjectState = AppContext::getAppSettings()->getUserAppsSettings()->getAskToSaveProject();
 
         QWidget* mainWindow = AppContext::getMainWindow()->getQMainWindow();
         int code;
-        if(silentSave == true){
+        if (silentSave) {
             code = QDialogButtonBox::Yes;
-        }else{
+        } else {
             code = savedSaveProjectState;
             if (QDialogButtonBox::NoButton == savedSaveProjectState) {
-                // QMessageBox::NoButton is a special invalid button state, represents that no saved choise was made
+                // QMessageBox::NoButton is a special invalid button state, represents that no saved choice was made
                 QObjectScopedPointer<SaveProjectDialogController> saveProjectDialog = new SaveProjectDialogController(mainWindow);
                 code = saveProjectDialog->exec();
                 CHECK_EXT(!saveProjectDialog.isNull(), setError("dialog is NULL"), );
@@ -164,7 +166,7 @@ void SaveProjectTask::prepare() {
                     code = QDialogButtonBox::Cancel;
                 }
 
-                if (QDialogButtonBox::Cancel != code && true == saveProjectDialog->dontAskCheckBox->isChecked()) {
+                if (QDialogButtonBox::Cancel != code && saveProjectDialog->dontAskCheckBox->isChecked()) {
                     AppContext::getAppSettings()->getUserAppsSettings()->setAskToSaveProject(code);
                 }
             }
@@ -182,7 +184,7 @@ void SaveProjectTask::prepare() {
 
             if (rc == QDialog::Accepted) {
                 AppContext::getProject()->setProjectName(d->projectNameEdit->text());
-                url = d->projectFolderEdit->text() + "/" + d->projectFileEdit->text();
+                url = d->projectFilePathEdit->text();
                 if (!url.endsWith(PROJECTFILE_EXT)) {
                     url.append(PROJECTFILE_EXT);
                 }
@@ -194,10 +196,10 @@ void SaveProjectTask::prepare() {
         }
     }
 
-    if (k!=SaveProjectTaskKind_SaveProjectOnly) {
+    if (k != SaveProjectTaskKind_SaveProjectOnly) {
         QList<Document*> modifiedDocs = SaveMultipleDocuments::findModifiedDocuments(AppContext::getProject()->getDocuments());
         if (!modifiedDocs.isEmpty()) {
-            ssTasks.append(new SaveMultipleDocuments(modifiedDocs, k == SaveProjectTaskKind_SaveProjectAndDocumentsAskEach, SavedNewDoc_Open));
+            ssTasks.append(new SaveMultipleDocuments(modifiedDocs, k == SaveProjectTaskKind_SaveProjectAndDocumentsAskEach));
         }
     }
     if (!url.isEmpty()) {
@@ -212,47 +214,44 @@ void SaveProjectTask::prepare() {
 /// SaveOnlyProjectTask
 
 SaveOnlyProjectTask::SaveOnlyProjectTask(Project* p, const QString& _url)
-: Task(tr("Save project"), TaskFlag_NoRun), sub(NULL), proj(p), url(_url)
-{
-        lock = NULL;
+    : Task(tr("Save project"), TaskFlag_NoRun), sub(nullptr), proj(p), url(_url) {
+    lock = nullptr;
 }
 
-SaveOnlyProjectTask::~SaveOnlyProjectTask(){
-    assert(lock == NULL);
+SaveOnlyProjectTask::~SaveOnlyProjectTask() {
+    assert(lock == nullptr);
 }
 
-void SaveOnlyProjectTask::prepare(){
-    if (proj == NULL) {
+void SaveOnlyProjectTask::prepare() {
+    if (proj == nullptr) {
         proj = AppContext::getProject();
     }
-    assert(proj!=NULL);
+    assert(proj != nullptr);
     if (url.isEmpty()) {
         url = proj->getProjectURL();
     }
 
-    foreach(Document *d, proj->getDocuments()){
-        
+    foreach (Document* d, proj->getDocuments()) {
         QStringList urls = d->getGHintsMap().value(ProjectLoaderHint_MultipleFilesMode_URLDocument, QStringList()).toStringList();
-        if(urls.isEmpty()){ // not merged document
+        if (urls.isEmpty()) {  // not merged document
             if (d->getURL().isLocalFile()) {
                 QFile pathToDoc(d->getURLString());
-                if (pathToDoc.exists()){
+                if (pathToDoc.exists()) {
                     continue;
                 }
                 phantomDocs.append(d);
             }
-        }
-        else{ // merged document
-            foreach(QString url, urls){
+        } else {  // merged document
+            for (const QString& url : qAsConst(urls)) {
                 QFile pathToDoc(url);
-                if (!pathToDoc.exists()){
+                if (!pathToDoc.exists()) {
                     phantomDocs.append(d);
                     break;
                 }
             }
         }
     }
-    if (!phantomDocs.isEmpty()){
+    if (!phantomDocs.isEmpty()) {
         sub = new RemoveMultipleDocumentsTask(proj, phantomDocs, false, false);
         addSubTask(sub);
     } else {
@@ -260,15 +259,15 @@ void SaveOnlyProjectTask::prepare(){
     }
 }
 
-QList<Task*> SaveOnlyProjectTask::onSubTaskFinished(Task* subTask){
+QList<Task*> SaveOnlyProjectTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> ret;
-    if (!isCanceled() && subTask == sub){
+    if (!isCanceled() && subTask == sub) {
         _run();
     }
     return ret;
 }
 
-void SaveOnlyProjectTask::_run(){
+void SaveOnlyProjectTask::_run() {
     lock = new StateLock(getTaskName(), StateLockFlag_LiveLock);
     proj->lockState(lock);
 
@@ -276,21 +275,20 @@ void SaveOnlyProjectTask::_run(){
     ProjectFileUtils::saveProjectFile(stateInfo, proj, url);
 }
 
-Task::ReportResult SaveOnlyProjectTask::report(){
+Task::ReportResult SaveOnlyProjectTask::report() {
     if (!stateInfo.hasError() && url == proj->getProjectURL()) {
         proj->setModified(false);
     }
     proj->unlockState(lock);
     delete lock;
-    lock = NULL;
+    lock = nullptr;
     return Task::ReportResult_Finished;
 }
 
 //////////////////////////////////////////////////////////////////////////
 /// LoadProjectTask
-LoadProjectTask::LoadProjectTask(const QString& _url) 
-    : Task(tr("Load project"), TaskFlag_None), proj(NULL), url(_url)
-{
+LoadProjectTask::LoadProjectTask(const QString& _url)
+    : Task(tr("Load project"), TaskFlag_None), proj(nullptr), url(_url) {
     xmlDoc = new QDomDocument();
 }
 
@@ -306,50 +304,45 @@ void LoadProjectTask::run() {
 
 Task::ReportResult LoadProjectTask::report() {
     if (!stateInfo.hasError()) {
-        ProjectParserRegistry *ppr = ProjectParserRegistry::instance();
-        ProjectParser *parser = ppr->getProjectParserByVersion(version);
-        if(parser == NULL){
+        ProjectParserRegistry* ppr = ProjectParserRegistry::instance();
+        ProjectParser* parser = ppr->getProjectParserByVersion(version);
+        if (parser == nullptr) {
             coreLog.info(tr("Unable to detect parser for project"));
             setError(tr("failed to parse project file %1").arg(url));
-        }else{
+        } else {
             proj = parser->createProjectFromXMLModel(url, *xmlDoc, stateInfo);
         }
-        if (proj!=NULL) {
+        if (proj != nullptr) {
             coreLog.info(tr("Project loaded: %1").arg(url));
-        } 
+        }
     }
     return Task::ReportResult_Finished;
 }
 
-
-
-
-RegisterProjectServiceTask::RegisterProjectServiceTask(Project* _proj) 
-    : Task(tr("Register project"), TaskFlag_NoRun), proj(_proj)
-{
+RegisterProjectServiceTask::RegisterProjectServiceTask(Project* _proj)
+    : Task(tr("Register project"), TaskFlag_NoRun), proj(_proj) {
 }
 
 void RegisterProjectServiceTask::prepare() {
-    ProjectServiceImpl* ps = new ProjectServiceImpl(proj);
+    auto ps = new ProjectServiceImpl(proj);
     addSubTask(AppContext::getServiceRegistry()->registerServiceTask(ps));
 }
 
-ExportProjectTask::ExportProjectTask(const QString& _destinationDir, const QString& _file, bool _compress):
-Task(tr("Export project task"), TaskFlags_NR_FOSCOE), compress(_compress), destinationDir(_destinationDir), projectFile(_file)
-{
+ExportProjectTask::ExportProjectTask(const QString& _destinationDir, const QString& _file, bool _compress)
+    : Task(tr("Export project task"), TaskFlags_NR_FOSCOE), compress(_compress), destinationDir(_destinationDir), projectFile(_file) {
     assert(!destinationDir.isEmpty());
     setVerboseLogMode(true);
 }
 
-void ExportProjectTask::prepare(){
-    Project *pr = AppContext::getProject();
+void ExportProjectTask::prepare() {
+    Project* pr = AppContext::getProject();
     if (pr->isItemModified()) {
-        //setting url in case of anonymous project
+        // setting url in case of anonymous project
         if (pr->getProjectURL().isEmpty()) {
             QString tempDir = AppContext::getAppSettings()->getUserAppsSettings()->getUserTemporaryDirPath();
             pr->setProjectURL(tempDir + QDir::separator() + projectFile);
-        }else{
-            addSubTask(new SaveProjectTask(SaveProjectTaskKind_SaveProjectAndDocuments, pr, QString::null, true));  
+        } else {
+            addSubTask(new SaveProjectTask(SaveProjectTaskKind_SaveProjectAndDocuments, pr, QString(), true));
         }
     }
 }
@@ -358,29 +351,29 @@ Task::ReportResult ExportProjectTask::report() {
     if (hasError() || isCanceled()) {
         return ReportResult_Finished;
     }
-    Project *pr = AppContext::getProject();
+    Project* pr = AppContext::getProject();
 
     QList<Document*> docList = pr->getDocuments();
-    foreach(Document* doc, docList){
-        if(doc->getURL().isEmpty()){
+    foreach (Document* doc, docList) {
+        if (doc->getURL().isEmpty()) {
             setError(tr("One of the project documents has empty URL"));
             return ReportResult_Finished;
         }
     }
-    
+
     QDir dDir(GUrlUtils::prepareDirLocation(destinationDir, stateInfo));
     CHECK_OP(stateInfo, ReportResult_Finished);
-    
+
     QMap<QString, QString> urlRemap;
-    foreach(Document* doc, docList){
+    foreach (Document* doc, docList) {
         QString origPath = doc->getURLString();
         IOAdapterId id = doc->getIOAdapterFactory()->getAdapterId();
-        if (id == BaseIOAdapters::LOCAL_FILE || id == BaseIOAdapters::GZIPPED_LOCAL_FILE){
+        if (id == BaseIOAdapters::LOCAL_FILE || id == BaseIOAdapters::GZIPPED_LOCAL_FILE) {
             QFile f(origPath);
             QFileInfo fi(f);
             QString resultPath = destinationDir + "/" + fi.fileName();
-            resultPath = GUrlUtils::rollFileName(resultPath, "_copy" , QSet<QString>());
-            if (resultPath != origPath && !f.copy(resultPath)){
+            resultPath = GUrlUtils::rollFileName(resultPath, "_copy", QSet<QString>());
+            if (resultPath != origPath && !f.copy(resultPath)) {
                 if (QFile::exists(resultPath)) {
                     setError(tr("Error during coping documents: file already exist"));
                 } else {
@@ -391,43 +384,42 @@ Task::ReportResult ExportProjectTask::report() {
             urlRemap[origPath] = GUrl(resultPath).getURLString();
         }
     }
-    if(pr->getProjectName().isEmpty()){
+    if (pr->getProjectName().isEmpty()) {
         QFileInfo fi(projectFile);
         pr->setProjectName(fi.baseName());
     }
- 
+
     ProjectFileUtils::saveProjectFile(stateInfo, pr, destinationDir + "/" + projectFile, urlRemap);
     return ReportResult_Finished;
 }
 
-
 //////////////////////////////////////////////////////////////////////////
 // tests
 
 void GTest_LoadProject::init(XMLTestFormat*, const QDomElement& el) {
-    addTaskResource(TaskResourceUsage( RESOURCE_PROJECT, 1, true));
+    addTaskResource(TaskResourceUsage(UGENE_RESOURCE_ID_PROJECT, 1, TaskResourceStage::Prepare));
     projContextName = el.attribute("index");
-    if(!el.attribute("load_from_temp").isEmpty()){
+    if (!el.attribute("load_from_temp").isEmpty()) {
         url = env->getVar("TEMP_DATA_DIR") + "/" + el.attribute("url");
-    }else{
+    } else {
         url = env->getVar("COMMON_DATA_DIR") + "/" + el.attribute("url");
     }
 }
 
-void GTest_LoadProject::prepare(){
+void GTest_LoadProject::prepare() {
     QList<Task*> tasks;
-    Project *previousProject = AppContext::getProject();
+    Project* previousProject = AppContext::getProject();
     ServiceRegistry* sr = AppContext::getServiceRegistry();
     QList<Service*> services = sr->findServices(Service_Project);
     int servSize = services.size();
     assert(servSize <= 1);
-    if(servSize == 1){
-        if (previousProject->metaObject() != NULL){
-            Task *tt  = new CloseProjectTask();
+    if (servSize == 1) {
+        if (previousProject->metaObject() != nullptr) {
+            Task* tt = new CloseProjectTask();
             tasks.append(tt);
         }
-    } else if(previousProject != NULL) {
-        AppContextImpl::getApplicationContext()->setProject(NULL);
+    } else if (previousProject != nullptr) {
+        AppContextImpl::getApplicationContext()->setProject(nullptr);
     }
     contextAdded = false;
 
@@ -438,8 +430,8 @@ void GTest_LoadProject::prepare(){
 }
 
 Task::ReportResult GTest_LoadProject::report() {
-    if (loadTask!=NULL && loadTask->hasError()) {
-        stateInfo.setError( loadTask->getError());
+    if (loadTask != nullptr && loadTask->hasError()) {
+        stateInfo.setError(loadTask->getError());
     } else if (!projContextName.isEmpty()) {
         addContext(projContextName, loadTask->getProject());
         contextAdded = true;
@@ -447,27 +439,26 @@ Task::ReportResult GTest_LoadProject::report() {
     return ReportResult_Finished;
 }
 
-QList<Task*> GTest_LoadProject::onSubTaskFinished( Task* subTask ){
+QList<Task*> GTest_LoadProject::onSubTaskFinished(Task* subTask) {
     QList<Task*> subTasks;
     if (subTask->hasError()) {
         return subTasks;
     }
     if (subTask == mt) {
-        Project *p = loadTask->getProject();
-        if(p != NULL){
+        Project* p = loadTask->getProject();
+        if (p != nullptr) {
             AppContextImpl::getApplicationContext()->setProject(p);
         }
     }
     return subTasks;
 }
 
-void GTest_LoadProject::cleanup(){
-    AppContextImpl::getApplicationContext()->setProject(NULL);
+void GTest_LoadProject::cleanup() {
+    AppContextImpl::getApplicationContext()->setProject(nullptr);
     XmlTest::cleanup();
 }
 
-
-QList<XMLTestFactory*> ProjectTests::createTestFactories(){
+QList<XMLTestFactory*> ProjectTests::createTestFactories() {
     QList<XMLTestFactory*> res;
     res.append(GTest_LoadProject::createFactory());
     res.append(GTest_ExportProject::createFactory());
@@ -476,22 +467,20 @@ QList<XMLTestFactory*> ProjectTests::createTestFactories(){
     return res;
 }
 
-void GTest_ExportProject::init(XMLTestFormat* tf, const QDomElement& el) {
-    Q_UNUSED(tf);
-    
-    exportTask = NULL;
+void GTest_ExportProject::init(XMLTestFormat*, const QDomElement& el) {
+    exportTask = nullptr;
     url = env->getVar("TEMP_DATA_DIR") + el.attribute("url");
 }
 
-void GTest_ExportProject::prepare(){
+void GTest_ExportProject::prepare() {
     QDir qd(url);
-    if(qd.exists(url)){
-        if(!removeDir(qd)){
+    if (qd.exists(url)) {
+        if (!removeDir(qd)) {
             stateInfo.setError(tr("GTest_ExportProject::prepare unable to clean folder for exporting"));
             return;
         }
-    }   
-    if(!qd.mkpath(url)){
+    }
+    if (!qd.mkpath(url)) {
         stateInfo.setError(tr("GTest_ExportProject::prepare unable to create folder for exporting"));
         return;
     }
@@ -499,8 +488,8 @@ void GTest_ExportProject::prepare(){
     addSubTask(exportTask);
 }
 
-Task::ReportResult GTest_ExportProject::report(){
-    if(exportTask!=NULL){
+Task::ReportResult GTest_ExportProject::report() {
+    if (exportTask != nullptr) {
         if (exportTask->hasError()) {
             stateInfo.setError(exportTask->getError());
         }
@@ -508,10 +497,10 @@ Task::ReportResult GTest_ExportProject::report(){
     return ReportResult_Finished;
 }
 
-void GTest_ExportProject::cleanup(){
+void GTest_ExportProject::cleanup() {
     QDir qd(url);
-    if(qd.exists(url)){
-        if(!removeDir(QDir(url))){
+    if (qd.exists(url)) {
+        if (!removeDir(QDir(url))) {
             coreLog.info(tr("GTest_ExportProject::cleanup unable to delete exported files"));
         }
     }
@@ -519,21 +508,20 @@ void GTest_ExportProject::cleanup(){
     XmlTest::cleanup();
 }
 
-bool GTest_ExportProject::removeDir( const QDir &aDir ){
+bool GTest_ExportProject::removeDir(const QDir& aDir) {
     bool has_err = false;
-    if (aDir.exists())//QDir::NoDotAndDotDot
+    if (aDir.exists())  // QDir::NoDotAndDotDot
     {
-        QFileInfoList entries = aDir.entryInfoList(QDir::NoDotAndDotDot | 
-            QDir::Dirs | QDir::Files);
+        QFileInfoList entries = aDir.entryInfoList(QDir::NoDotAndDotDot |
+                                                   QDir::Dirs | QDir::Files);
         int count = entries.size();
-        for (int idx = 0; idx < count; idx++)
-        {
+        for (int idx = 0; idx < count; idx++) {
             QFileInfo entryInfo = entries[idx];
             QString path = entryInfo.canonicalFilePath();
-            if (entryInfo.isDir()){
+            if (entryInfo.isDir()) {
                 QDir aaa(path);
-                has_err = removeDir( aaa );
-            }else{
+                has_err = removeDir(aaa);
+            } else {
                 QFile file(path);
                 if (!file.remove())
                     has_err = true;
@@ -542,68 +530,64 @@ bool GTest_ExportProject::removeDir( const QDir &aDir ){
         if (!aDir.rmdir(aDir.absolutePath()))
             has_err = true;
     }
-    return(has_err);
+    return (has_err);
 }
-void GTest_UnloadProject::init(XMLTestFormat* tf, const QDomElement& el) {
-    Q_UNUSED(tf);
-
+void GTest_UnloadProject::init(XMLTestFormat*, const QDomElement& el) {
     QString packedList = el.attribute("documents");
-    if(packedList.isEmpty()){
-        //document list can be empty!
+    if (packedList.isEmpty()) {
+        // document list can be empty!
         return;
     }
     unloadDocList = packedList.split(",");
 }
 
-void GTest_UnloadProject::prepare(){
-    Project *p = AppContext::getProject();
-    if(p != NULL){
-        foreach(QString doc, unloadDocList){
+void GTest_UnloadProject::prepare() {
+    Project* p = AppContext::getProject();
+    if (p != nullptr) {
+        foreach (QString doc, unloadDocList) {
             removeContext(doc);
         }
-        AppContextImpl::getApplicationContext()->setProject(NULL);
+        AppContextImpl::getApplicationContext()->setProject(nullptr);
     }
 }
 
-void GTest_LoadDocumentFromProject::init(XMLTestFormat* tf, const QDomElement& el) {
-    Q_UNUSED(tf);
-
+void GTest_LoadDocumentFromProject::init(XMLTestFormat*, const QDomElement& el) {
     documentFileName = el.attribute("document");
     contextAdded = false;
 }
 
-void GTest_LoadDocumentFromProject::prepare(){
-    Project *pr = AppContext::getProject();
-    if (pr == NULL){
+void GTest_LoadDocumentFromProject::prepare() {
+    Project* pr = AppContext::getProject();
+    if (pr == nullptr) {
         stateInfo.setError(tr("No project loaded"));
         return;
     }
-    if (documentFileName.isEmpty()){
+    if (documentFileName.isEmpty()) {
         stateInfo.setError(tr("Document name to load is empty"));
         return;
     }
-    foreach(Document *doc, pr->getDocuments()){
+    foreach (Document* doc, pr->getDocuments()) {
         QFileInfo fi(doc->getURLString());
-        QString tmp  = fi.fileName();
-        if (fi.fileName() == documentFileName){
-            if(!doc->isLoaded()){
+        QString tmp = fi.fileName();
+        if (fi.fileName() == documentFileName) {
+            if (!doc->isLoaded()) {
                 loadTask = new LoadUnloadedDocumentTask(doc);
                 addSubTask(loadTask);
             }
             loadedDoc = doc;
         }
     }
-    if (loadedDoc == NULL){
+    if (loadedDoc == nullptr) {
         stateInfo.setError(tr("File %1 not found in project").arg(documentFileName));
         return;
     }
 }
 
-void GTest_LoadDocumentFromProject::cleanup(){
-    QObject *o = getContext(documentFileName);
-    if(contextAdded && o != NULL){
+void GTest_LoadDocumentFromProject::cleanup() {
+    QObject* o = getContext(documentFileName);
+    if (contextAdded && o != nullptr) {
         removeContext(documentFileName);
-        if(loadedDoc->isLoaded()){
+        if (loadedDoc->isLoaded()) {
             AppContext::getTaskScheduler()->registerTopLevelTask(new UnloadDocumentTask(loadedDoc, false));
         }
     }
@@ -611,9 +595,9 @@ void GTest_LoadDocumentFromProject::cleanup(){
     XmlTest::cleanup();
 }
 
-Task::ReportResult GTest_LoadDocumentFromProject::report(){
-    if(loadTask!=NULL){
-        if(!loadTask->hasError()){
+Task::ReportResult GTest_LoadDocumentFromProject::report() {
+    if (loadTask != nullptr) {
+        if (!loadTask->hasError()) {
             addContext(documentFileName, loadedDoc);
             contextAdded = true;
         }
@@ -621,4 +605,4 @@ Task::ReportResult GTest_LoadDocumentFromProject::report(){
     return ReportResult_Finished;
 }
 
-} //namespace
+}  // namespace U2
